@@ -257,27 +257,22 @@ SECStatus
 CERT_IssuerNameFromDERCert(SECItem *derCert, SECItem *derName)
 {
     int rv;
-    PLArenaPool *arena;
+    PORTCheapArenaPool tmpArena;
     CERTSignedData sd;
     void *tmpptr;
 
-    arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
-
-    if (!arena) {
-        return (SECFailure);
-    }
+    PORT_InitCheapArena(&tmpArena, DER_DEFAULT_CHUNKSIZE);
 
     PORT_Memset(&sd, 0, sizeof(CERTSignedData));
-    rv = SEC_QuickDERDecodeItem(arena, &sd, CERT_SignedDataTemplate, derCert);
-
+    rv = SEC_QuickDERDecodeItem(&tmpArena.arena, &sd, CERT_SignedDataTemplate,
+                                derCert);
     if (rv) {
         goto loser;
     }
 
     PORT_Memset(derName, 0, sizeof(SECItem));
-    rv = SEC_QuickDERDecodeItem(arena, derName, SEC_CertIssuerTemplate,
-                                &sd.data);
-
+    rv = SEC_QuickDERDecodeItem(&tmpArena.arena, derName,
+                                SEC_CertIssuerTemplate, &sd.data);
     if (rv) {
         goto loser;
     }
@@ -290,11 +285,11 @@ CERT_IssuerNameFromDERCert(SECItem *derCert, SECItem *derName)
 
     PORT_Memcpy(derName->data, tmpptr, derName->len);
 
-    PORT_FreeArena(arena, PR_FALSE);
+    PORT_DestroyCheapArena(&tmpArena);
     return (SECSuccess);
 
 loser:
-    PORT_FreeArena(arena, PR_FALSE);
+    PORT_DestroyCheapArena(&tmpArena);
     return (SECFailure);
 }
 
@@ -302,27 +297,22 @@ SECStatus
 CERT_SerialNumberFromDERCert(SECItem *derCert, SECItem *derName)
 {
     int rv;
-    PLArenaPool *arena;
+    PORTCheapArenaPool tmpArena;
     CERTSignedData sd;
     void *tmpptr;
 
-    arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
-
-    if (!arena) {
-        return (SECFailure);
-    }
+    PORT_InitCheapArena(&tmpArena, DER_DEFAULT_CHUNKSIZE);
 
     PORT_Memset(&sd, 0, sizeof(CERTSignedData));
-    rv = SEC_QuickDERDecodeItem(arena, &sd, CERT_SignedDataTemplate, derCert);
-
+    rv = SEC_QuickDERDecodeItem(&tmpArena.arena, &sd, CERT_SignedDataTemplate,
+                                derCert);
     if (rv) {
         goto loser;
     }
 
     PORT_Memset(derName, 0, sizeof(SECItem));
-    rv = SEC_QuickDERDecodeItem(arena, derName, SEC_CertSerialNumberTemplate,
-                                &sd.data);
-
+    rv = SEC_QuickDERDecodeItem(&tmpArena.arena, derName,
+                                SEC_CertSerialNumberTemplate, &sd.data);
     if (rv) {
         goto loser;
     }
@@ -335,11 +325,11 @@ CERT_SerialNumberFromDERCert(SECItem *derCert, SECItem *derName)
 
     PORT_Memcpy(derName->data, tmpptr, derName->len);
 
-    PORT_FreeArena(arena, PR_FALSE);
+    PORT_DestroyCheapArena(&tmpArena);
     return (SECSuccess);
 
 loser:
-    PORT_FreeArena(arena, PR_FALSE);
+    PORT_DestroyCheapArena(&tmpArena);
     return (SECFailure);
 }
 
@@ -400,8 +390,7 @@ GetKeyUsage(CERTCertificate *cert)
 
         PORT_Free(tmpitem.data);
         tmpitem.data = NULL;
-    }
-    else {
+    } else {
         /* if the extension is not present, then we allow all uses */
         cert->keyUsage = KU_ALL;
         cert->rawKeyUsage = KU_ALL;
@@ -483,8 +472,7 @@ cert_ComputeCertType(CERTCertificate *cert)
     if (tmpitem.data != NULL || extKeyUsage != NULL) {
         if (tmpitem.data == NULL) {
             nsCertType = 0;
-        }
-        else {
+        } else {
             nsCertType = tmpitem.data[0];
         }
 
@@ -517,8 +505,7 @@ cert_ComputeCertType(CERTCertificate *cert)
             SECSuccess) {
             if (basicConstraintPresent == PR_TRUE && (basicConstraint.isCA)) {
                 nsCertType |= NS_CERT_TYPE_EMAIL_CA;
-            }
-            else {
+            } else {
                 nsCertType |= NS_CERT_TYPE_EMAIL;
             }
         }
@@ -526,8 +513,7 @@ cert_ComputeCertType(CERTCertificate *cert)
                 extKeyUsage, SEC_OID_EXT_KEY_USAGE_SERVER_AUTH) == SECSuccess) {
             if (basicConstraintPresent == PR_TRUE && (basicConstraint.isCA)) {
                 nsCertType |= NS_CERT_TYPE_SSL_CA;
-            }
-            else {
+            } else {
                 nsCertType |= NS_CERT_TYPE_SSL_SERVER;
             }
         }
@@ -540,8 +526,7 @@ cert_ComputeCertType(CERTCertificate *cert)
             SECSuccess) {
             if (basicConstraintPresent == PR_TRUE && (basicConstraint.isCA)) {
                 nsCertType |= NS_CERT_TYPE_SSL_CA;
-            }
-            else {
+            } else {
                 nsCertType |= NS_CERT_TYPE_SSL_SERVER;
             }
         }
@@ -549,8 +534,7 @@ cert_ComputeCertType(CERTCertificate *cert)
                 extKeyUsage, SEC_OID_EXT_KEY_USAGE_CLIENT_AUTH) == SECSuccess) {
             if (basicConstraintPresent == PR_TRUE && (basicConstraint.isCA)) {
                 nsCertType |= NS_CERT_TYPE_SSL_CA;
-            }
-            else {
+            } else {
                 nsCertType |= NS_CERT_TYPE_SSL_CLIENT;
             }
         }
@@ -558,8 +542,7 @@ cert_ComputeCertType(CERTCertificate *cert)
                 extKeyUsage, SEC_OID_EXT_KEY_USAGE_CODE_SIGN) == SECSuccess) {
             if (basicConstraintPresent == PR_TRUE && (basicConstraint.isCA)) {
                 nsCertType |= NS_CERT_TYPE_OBJECT_SIGNING_CA;
-            }
-            else {
+            } else {
                 nsCertType |= NS_CERT_TYPE_OBJECT_SIGNING;
             }
         }
@@ -571,8 +554,7 @@ cert_ComputeCertType(CERTCertificate *cert)
             SECSuccess) {
             nsCertType |= EXT_KEY_USAGE_STATUS_RESPONDER;
         }
-    }
-    else {
+    } else {
         /* If no NS Cert Type extension and no EKU extension, then */
         nsCertType = 0;
         if (CERT_IsCACert(cert, &nsCertType))
@@ -674,8 +656,7 @@ cert_IsRootCert(CERTCertificate *cert)
                 PORT_Free(tmpitem.data);
                 if (!match)
                     return PR_FALSE; /* else fall through */
-            }
-            else {
+            } else {
                 /* the subject key ID is required when AKI is present */
                 return PR_FALSE;
             }
@@ -743,8 +724,7 @@ CERT_DecodeDERCertificate(SECItem *derSignedCert, PRBool copyDER,
         cert->derCert.data = (unsigned char *)data;
         cert->derCert.len = derSignedCert->len;
         PORT_Memcpy(data, derSignedCert->data, derSignedCert->len);
-    }
-    else {
+    } else {
         /* point to passed in DER data */
         cert->derCert = *derSignedCert;
     }
@@ -771,8 +751,7 @@ CERT_DecodeDERCertificate(SECItem *derSignedCert, PRBool copyDER,
     /* set the nickname */
     if (nickname == NULL) {
         cert->nickname = NULL;
-    }
-    else {
+    } else {
         /* copy and install the nickname */
         len = PORT_Strlen(nickname) + 1;
         cert->nickname = (char *)PORT_ArenaAlloc(arena, len);
@@ -1007,8 +986,7 @@ SEC_GetCrlTimes(CERTCrl *date, PRTime *notBefore, PRTime *notAfter)
         if (rv) {
             return (SECFailure);
         }
-    }
-    else {
+    } else {
         LL_I2L(*notAfter, 0L);
     }
     return (SECSuccess);
@@ -1132,8 +1110,7 @@ CERT_KeyUsageAndTypeForCertUsage(SECCertUsage usage, PRBool ca,
                 PORT_Assert(0);
                 goto loser;
         }
-    }
-    else {
+    } else {
         switch (usage) {
             case certUsageSSLClient:
                 /*
@@ -1318,12 +1295,16 @@ CERT_AddOKDomainName(CERTCertificate *cert, const char *hn)
         PORT_SetError(SEC_ERROR_INVALID_ARGS);
         return SECFailure;
     }
-    domainOK = (CERTOKDomainName *)PORT_ArenaZAlloc(
-        cert->arena, (sizeof *domainOK) + newNameLen);
-    if (!domainOK)
+    domainOK = (CERTOKDomainName *)PORT_ArenaZAlloc(cert->arena, sizeof(*domainOK));
+    if (!domainOK) {
         return SECFailure; /* error code is already set. */
+    }
+    domainOK->name = (char *)PORT_ArenaZAlloc(cert->arena, newNameLen + 1);
+    if (!domainOK->name) {
+        return SECFailure; /* error code is already set. */
+    }
 
-    PORT_Strcpy(domainOK->name, hn);
+    PORT_Strncpy(domainOK->name, hn, newNameLen + 1);
     sec_lower_string(domainOK->name);
 
     /* put at head of list. */
@@ -1344,7 +1325,7 @@ cert_TestHostName(char *cn, const char *hn)
     static int useShellExp = -1;
 
     if (useShellExp < 0) {
-        useShellExp = (NULL != PR_GetEnv("NSS_USE_SHEXP_IN_CERT_NAME"));
+        useShellExp = (NULL != PR_GetEnvSecure("NSS_USE_SHEXP_IN_CERT_NAME"));
     }
     if (useShellExp) {
         /* Backward compatible code, uses Shell Expressions (SHEXP). */
@@ -1356,15 +1337,13 @@ cert_TestHostName(char *cn, const char *hn)
 
             if (match == 0) {
                 rv = SECSuccess;
-            }
-            else {
+            } else {
                 PORT_SetError(SSL_ERROR_BAD_CERT_DOMAIN);
                 rv = SECFailure;
             }
             return rv;
         }
-    }
-    else {
+    } else {
         /* New approach conforms to RFC 6125. */
         char *wildcard = PORT_Strchr(cn, '*');
         char *firstcndot = PORT_Strchr(cn, '.');
@@ -1379,9 +1358,8 @@ cert_TestHostName(char *cn, const char *hn)
          * - must not be preceded by an IDNA ACE prefix (xn--)
          */
         if (wildcard && secondcndot && secondcndot[1] && firsthndot &&
-            firstcndot - wildcard ==
-                1 /* wildcard is last char in first component */
-            && secondcndot - firstcndot > 1 /* second component is non-empty */
+            firstcndot - wildcard == 1           /* wildcard is last char in first component */
+            && secondcndot - firstcndot > 1      /* second component is non-empty */
             && PORT_Strrchr(cn, '*') == wildcard /* only one wildcard in cn */
             && !PORT_Strncasecmp(cn, hn, wildcard - cn) &&
             !PORT_Strcasecmp(firstcndot, firsthndot)
@@ -1428,7 +1406,6 @@ cert_VerifySubjectAltName(const CERTCertificate *cert, const char *hn)
         goto fail;
     }
     isIPaddr = (PR_SUCCESS == PR_StringToNetAddr(hn, &netAddr));
-    rv = SECFailure;
     arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
     if (!arena)
         goto fail;
@@ -1473,23 +1450,20 @@ cert_VerifySubjectAltName(const CERTCertificate *cert, const char *hn)
                         netAddr.inet.family == PR_AF_INET) {
                         match = !memcmp(&netAddr.inet.ip,
                                         current->name.other.data, 4);
-                    }
-                    else if (current->name.other.len ==
-                                 16 && /* IP v6 address */
-                             netAddr.ipv6.family == PR_AF_INET6) {
+                    } else if (current->name.other.len ==
+                                   16 && /* IP v6 address */
+                               netAddr.ipv6.family == PR_AF_INET6) {
                         match = !memcmp(&netAddr.ipv6.ip,
                                         current->name.other.data, 16);
-                    }
-                    else if (current->name.other.len ==
-                                 16 && /* IP v6 address */
-                             netAddr.inet.family == PR_AF_INET) {
+                    } else if (current->name.other.len ==
+                                   16 && /* IP v6 address */
+                               netAddr.inet.family == PR_AF_INET) {
                         /* convert netAddr to ipv6, then compare. */
                         /* ipv4 must be in Network Byte Order on input. */
                         PR_ConvertIPv4AddrToIPv6(netAddr.inet.ip, &v6Addr);
                         match = !memcmp(&v6Addr, current->name.other.data, 16);
-                    }
-                    else if (current->name.other.len == 4 && /* IP v4 address */
-                             netAddr.inet.family == PR_AF_INET6) {
+                    } else if (current->name.other.len == 4 && /* IP v4 address */
+                               netAddr.inet.family == PR_AF_INET6) {
                         /* convert netAddr to ipv6, then compare. */
                         PRUint32 ipv4 = (current->name.other.data[0] << 24) |
                                         (current->name.other.data[1] << 16) |
@@ -1517,8 +1491,7 @@ fail:
     if (!(isIPaddr ? IPextCount : DNSextCount)) {
         /* no relevant value in the extension was found. */
         PORT_SetError(SEC_ERROR_EXTENSION_NOT_FOUND);
-    }
-    else {
+    } else {
         PORT_SetError(SSL_ERROR_BAD_CERT_DOMAIN);
     }
     rv = SECFailure;
@@ -1648,8 +1621,7 @@ cert_GetDNSPatternsFromGeneralNames(CERTGeneralName *firstName,
                     addr.inet.family = PR_AF_INET;
                     memcpy(&addr.inet.ip, currentInput->name.other.data,
                            currentInput->name.other.len);
-                }
-                else if (currentInput->name.other.len == 16) {
+                } else if (currentInput->name.other.len == 16) {
                     addr.ipv6.family = PR_AF_INET6;
                     memcpy(&addr.ipv6.ip, currentInput->name.other.data,
                            currentInput->name.other.len);
@@ -1787,18 +1759,15 @@ CERT_VerifyCertName(const CERTCertificate *cert, const char *hn)
         if (isIPaddr) {
             if (PORT_Strcasecmp(hn, cn) == 0) {
                 rv = SECSuccess;
-            }
-            else {
+            } else {
                 PORT_SetError(SSL_ERROR_BAD_CERT_DOMAIN);
                 rv = SECFailure;
             }
-        }
-        else {
+        } else {
             rv = cert_TestHostName(cn, hn);
         }
         PORT_Free(cn);
-    }
-    else
+    } else
         PORT_SetError(SSL_ERROR_BAD_CERT_DOMAIN);
     return rv;
 }
@@ -1811,8 +1780,7 @@ CERT_CompareCerts(const CERTCertificate *c1, const CERTCertificate *c2)
     comp = SECITEM_CompareItem(&c1->derCert, &c2->derCert);
     if (comp == SECEqual) { /* certs are the same */
         return (PR_TRUE);
-    }
-    else {
+    } else {
         return (PR_FALSE);
     }
 }
@@ -1966,8 +1934,7 @@ CERT_MakeCANickname(CERTCertificate *cert)
             if (firstname) {
                 org = firstname;
                 firstname = NULL;
-            }
-            else {
+            } else {
                 org = PORT_Strdup("Unknown CA");
             }
         }
@@ -1985,16 +1952,13 @@ CERT_MakeCANickname(CERTCertificate *cert)
         if (firstname) {
             if (count == 1) {
                 nickname = PR_smprintf("%s - %s", firstname, org);
-            }
-            else {
+            } else {
                 nickname = PR_smprintf("%s - %s #%d", firstname, org, count);
             }
-        }
-        else {
+        } else {
             if (count == 1) {
                 nickname = PR_smprintf("%s", org);
-            }
-            else {
+            } else {
                 nickname = PR_smprintf("%s #%d", org, count);
             }
         }
@@ -2101,37 +2065,29 @@ CERT_IsCACert(CERTCertificate *cert, unsigned int *rettype)
     unsigned int cType = cert->nsCertType;
     PRBool ret = PR_FALSE;
 
-    if (cType & (NS_CERT_TYPE_SSL_CA | NS_CERT_TYPE_EMAIL_CA |
-                 NS_CERT_TYPE_OBJECT_SIGNING_CA)) {
-        ret = PR_TRUE;
-    }
-    else {
-        SECStatus rv;
-        CERTBasicConstraints constraints;
-
-        rv = CERT_FindBasicConstraintExten(cert, &constraints);
-        if (rv == SECSuccess && constraints.isCA) {
-            ret = PR_TRUE;
-            cType |= (NS_CERT_TYPE_SSL_CA | NS_CERT_TYPE_EMAIL_CA);
-        }
-    }
-
-    /* finally check if it's an X.509 v1 root CA */
-    if (!ret &&
-        (cert->isRoot && cert_Version(cert) < SEC_CERTIFICATE_VERSION_3)) {
-        ret = PR_TRUE;
+    /*
+     * Check if the constraints are available and it's a CA, OR if it's
+     * a X.509 v1 Root CA.
+     */
+    CERTBasicConstraints constraints;
+    if ((CERT_FindBasicConstraintExten(cert, &constraints) == SECSuccess &&
+         constraints.isCA) ||
+        (cert->isRoot && cert_Version(cert) < SEC_CERTIFICATE_VERSION_3))
         cType |= (NS_CERT_TYPE_SSL_CA | NS_CERT_TYPE_EMAIL_CA);
-    }
-    /* Now apply trust overrides, if any */
+
+    /*
+     * Apply trust overrides, if any.
+     */
     cType = cert_ComputeTrustOverrides(cert, cType);
     ret = (cType & (NS_CERT_TYPE_SSL_CA | NS_CERT_TYPE_EMAIL_CA |
                     NS_CERT_TYPE_OBJECT_SIGNING_CA))
               ? PR_TRUE
               : PR_FALSE;
 
-    if (rettype != NULL) {
+    if (rettype) {
         *rettype = cType;
     }
+
     return ret;
 }
 
@@ -2254,8 +2210,7 @@ CERT_IsNewer(CERTCertificate *certa, CERTCertificate *certb)
             return (PR_FALSE);
         }
         return (PR_TRUE);
-    }
-    else {
+    } else {
         /* cert B was issued after cert A, but expires sooner */
         /* if B is expired, then pick A */
         if (LL_CMP(notAfterB, <, now)) {
@@ -2371,8 +2326,7 @@ CERT_DecodeTrustString(CERTCertTrust *trust, const char *trusts)
             case ',':
                 if (pflags == &trust->sslFlags) {
                     pflags = &trust->emailFlags;
-                }
-                else {
+                } else {
                     pflags = &trust->objectSigningFlags;
                 }
                 break;
@@ -2489,8 +2443,7 @@ CERT_ImportCerts(CERTCertDBHandle *certdb, SECCertUsage usage,
                      */
                     /* Bug 1192442 - propagate errors from these calls. */
                     (void)CERT_AddTempCertToPerm(certs[i], canickname, NULL);
-                }
-                else {
+                } else {
                     (void)CERT_AddTempCertToPerm(
                         certs[i], nickname ? nickname : canickname, NULL);
                 }
@@ -2503,8 +2456,7 @@ CERT_ImportCerts(CERTCertDBHandle *certdb, SECCertUsage usage,
 
     if (retCerts) {
         *retCerts = certs;
-    }
-    else {
+    } else {
         if (certs) {
             CERT_DestroyCertArray(certs, fcerts);
         }
@@ -2607,9 +2559,9 @@ CERT_AddCertToListHeadWithData(CERTCertList *certs, CERTCertificate *cert,
     CERTCertListNode *head;
 
     head = CERT_LIST_HEAD(certs);
-
-    if (head == NULL)
-        return CERT_AddCertToListTail(certs, cert);
+    if (head == NULL) {
+        goto loser;
+    }
 
     node = (CERTCertListNode *)PORT_ArenaZAlloc(certs->arena,
                                                 sizeof(CERTCertListNode));
@@ -2700,8 +2652,7 @@ CERT_SortCBValidity(CERTCertificate *certa, CERTCertificate *certb, void *arg)
     if (newerbefore) {
         /* cert A was issued after cert B, but expires sooner */
         return (PR_TRUE);
-    }
-    else {
+    } else {
         /* cert B was issued after cert A, but expires sooner */
         return (PR_FALSE);
     }
@@ -2800,8 +2751,7 @@ CERT_FilterCertListByUsage(CERTCertList *certList, SECCertUsage usage,
                  * fix the cert decoding code to do this.
                  */
                 (void)CERT_IsCACert(node->cert, &certType);
-            }
-            else {
+            } else {
                 certType = node->cert->nsCertType;
             }
             if (!(certType & requiredCertType)) {
@@ -2814,8 +2764,7 @@ CERT_FilterCertListByUsage(CERTCertList *certList, SECCertUsage usage,
             savenode = CERT_LIST_NEXT(node);
             CERT_RemoveCertListNode(node);
             node = savenode;
-        }
-        else {
+        } else {
             node = CERT_LIST_NEXT(node);
         }
     }
@@ -2836,8 +2785,7 @@ CERT_IsUserCert(CERTCertificate *cert)
         ((trust.sslFlags & CERTDB_USER) || (trust.emailFlags & CERTDB_USER) ||
          (trust.objectSigningFlags & CERTDB_USER))) {
         return PR_TRUE;
-    }
-    else {
+    } else {
         return PR_FALSE;
     }
 }
@@ -2861,8 +2809,7 @@ CERT_FilterCertListForUserCerts(CERTCertList *certList)
             freenode = node;
             node = CERT_LIST_NEXT(node);
             CERT_RemoveCertListNode(freenode);
-        }
-        else {
+        } else {
             /* Is a User cert, so leave it in the list */
             node = CERT_LIST_NEXT(node);
         }
@@ -2918,7 +2865,18 @@ CERT_LockCertTrust(const CERTCertificate *cert)
 {
     PORT_Assert(certTrustLock != NULL);
     PZ_Lock(certTrustLock);
-    return;
+}
+
+static PZLock *certTempPermLock = NULL;
+
+/*
+ * Acquire the cert temp/perm lock
+ */
+void
+CERT_LockCertTempPerm(const CERTCertificate *cert)
+{
+    PORT_Assert(certTempPermLock != NULL);
+    PZ_Lock(certTempPermLock);
 }
 
 SECStatus
@@ -2942,6 +2900,18 @@ cert_InitLocks(void)
         }
     }
 
+    if (certTempPermLock == NULL) {
+        certTempPermLock = PZ_NewLock(nssILockCertDB);
+        PORT_Assert(certTempPermLock != NULL);
+        if (!certTempPermLock) {
+            PZ_DestroyLock(certTrustLock);
+            PZ_DestroyLock(certRefCountLock);
+            certRefCountLock = NULL;
+            certTrustLock = NULL;
+            return SECFailure;
+        }
+    }
+
     return SECSuccess;
 }
 
@@ -2954,8 +2924,7 @@ cert_DestroyLocks(void)
     if (certRefCountLock) {
         PZ_DestroyLock(certRefCountLock);
         certRefCountLock = NULL;
-    }
-    else {
+    } else {
         rv = SECFailure;
     }
 
@@ -2963,8 +2932,15 @@ cert_DestroyLocks(void)
     if (certTrustLock) {
         PZ_DestroyLock(certTrustLock);
         certTrustLock = NULL;
+    } else {
+        rv = SECFailure;
     }
-    else {
+
+    PORT_Assert(certTempPermLock != NULL);
+    if (certTempPermLock) {
+        PZ_DestroyLock(certTempPermLock);
+        certTempPermLock = NULL;
+    } else {
         rv = SECFailure;
     }
     return rv;
@@ -2988,6 +2964,23 @@ CERT_UnlockCertTrust(const CERTCertificate *cert)
 #endif
 }
 
+/*
+ * Free the temp/perm lock
+ */
+void
+CERT_UnlockCertTempPerm(const CERTCertificate *cert)
+{
+    PORT_Assert(certTempPermLock != NULL);
+#ifdef DEBUG
+    {
+        PRStatus prstat = PZ_Unlock(certTempPermLock);
+        PORT_Assert(prstat == PR_SUCCESS);
+    }
+#else
+    (void)PZ_Unlock(certTempPermLock);
+#endif
+}
+
 /*
  * Get the StatusConfig data for this handle
  */
